# Icom IC-7610 Drivers

Low-level transport drivers for IC-7610 serial backend.

## Modules

- `serial_civ_link.py` — Serial CI-V transport
- `serial_session.py` — USB serial session management
- `usb_audio.py` — USB audio device handling (macOS)
- `contracts.py` — Driver contracts and types

## See Also

- [Transport](transport.md)
- [Serial Backend](backends-icom7610.md)
